import BD from '../connection.js';
import ExceptionHandler from '../Exceptions/ExceptionHandler.js';
import NovoCodigo from '../Providers/NovoCodigo.js';
import Status from './Status.js';

const IntegracaoCardapio = {
    PRATO_PARAMS: ["prato", "nrPratoCardapio", "unidadePrato", "percentualConsumo", "tipoPrato"],
    DIA_PARAMS: ["dia", "comensais", "pratos"],
    REQUEST_PARAMS: ["cardapio", "NRCENARIOCARD"],
    CARDAPIO_PARAMS: ["unidade", "servico", "mes", "operador", "datas"],
    callback: {},
    handleCallback() {
        let callback = {};
        if (this.callback.hasErrors) {
            unset(this.callback.hasErrors);
            callback = {
                "sucesso" : false,
                "erros"   : this.callback,
            };
        } else {
            callback = {
                "sucesso" : true,
            };
        }
        return callback;
    },
    arrayDiff(arr1, arr2){
        return arr1.filter( param => !arr2.includes(param));
    },
    buildFilterForRow(procedureErrors) {
        return {
            "NRLOGINTCARDAMES": procedureErrors.NRLOGINTCARDAMES, // general error
            "NRLOGINTCARDADIA": procedureErrors.NRLOGINTCARDADIA, // day error
            "NRLOGINTCOMPCARD": procedureErrors.NRLOGINTCOMPCARD, // plate error
        };
    },
    async getDayFromLogintcardadia(NRLOGINTCARDADIA) {
        const SQL_LOGINTCARDADIA = "SELECT TRUNC(DTCARDAPIO) AS DTCARDAPIO FROM LOGINTCARDADIA WHERE NRLOGINTCARDADIA = :NRLOGINTCARDADIA";
        let queryParameters = {
            NRLOGINTCARDADIA,
        };
        let result = await BD.execQuery( SQL_LOGINTCARDADIA, queryParameters );
        if(Array.isArray(result) && result.length){
            const [ FIRST_RECORD ] = result;
            return FIRST_RECORD;
        }
        return {};
    },
    async setDayErrorOnCallback(curProError, NRLOGINTCARDADIA) {
        let dayWithError = await this.getDayFromLogintcardadia(NRLOGINTCARDADIA);
        this.callback.cardapio.datas.forEach( currData => {
            const DTCARDAPIO = dayWithError.DTCARDAPIO.split(' 00:00:00').join('');
            if (currData.dia == DTCARDAPIO) {
                currData.errors.push(`${curProError.DSITEM} - ${curProError.DSERRO}`);
            }
        });
    },
    setGeneralErrorOnCallback(curProError) {
        this.callback.cardapio.errors.push(`${curProError.DSITEM} - ${curProError.DSERRO}`);
    },
    async getPlateFromLogIntCompCard(NRLOGINTCOMPCARD) {
        const SQL_LOG = `SELECT LICD.DTCARDAPIO AS DTCARDAPIO , LICC.CDPRATO AS CDPRATO , LICC.CDTIPOPRAT AS CDTIPOPRAT , LICC.CDFILAUXPRAT AS CDFILAUXPRAT FROM LOGINTCOMPCARD LICC INNER JOIN LOGINTCARDADIA LICD ON LICD.NRLOGINTCARDADIA = LICC.NRLOGINTCARDADIA WHERE NRLOGINTCOMPCARD = :NRLOGINTCOMPCARD`;
        let queryParameters = {
            NRLOGINTCOMPCARD: {val: NRLOGINTCOMPCARD},
        };
        let result = await BD.execQuery(SQL_LOG, queryParameters);
        if(Array.isArray(result) && result.length){
            const [ FIRST_RECORD ] = result;
            return FIRST_RECORD;
        }
        return {};
    },
    async setPlateErrorOnCallback(curProError, NRLOGINTCOMPCARD) {
        let plateWithError = await this.getPlateFromLogIntCompCard(NRLOGINTCOMPCARD);
        const { DSITEM, DSERRO } = curProError;
        this.callback.cardapio.datas.forEach( currData => {
            currData.pratos.forEach( currPlate => {
                const DTCARDAPIO = plateWithError.DTCARDAPIO.split(' 00:00:00').join('');
                const { prato, tipoPrato, unidadePrato } = currPlate;
                const { CDPRATO, CDTIPOPRAT, CDFILAUXPRAT } = plateWithError;
                if ( currData.dia == DTCARDAPIO && prato == CDPRATO && tipoPrato == CDTIPOPRAT && unidadePrato == CDFILAUXPRAT) {
                    currPlate.errors.push(`${DSITEM} - ${DSERRO}`);
                }
            });
        });
    },
    async setErrorsFromProcedure(nrlogintcardames) {
        let procedureErrors = this.getErrorsFromProcedure(nrlogintcardames);
        if(Array.isArray(procedureErrors) && procedureErrors.length){
            procedureErrors.forEach( curProError => {
                let flowDivider = this.buildFilterForRow(curProError);
                const { NRLOGINTCARDADIA, NRLOGINTCOMPCARD} = flowDivider
                if (NRLOGINTCARDADIA == null && NRLOGINTCOMPCARD == null) {
                    this.setGeneralErrorOnCallback(curProError); // General Error
                } else if (NRLOGINTCARDADIA != null) {
                    this.setDayErrorOnCallback(curProError, NRLOGINTCARDADIA); // Day Error
                } else if (NRLOGINTCOMPCARD != null) {
                    this.setPlateErrorOnCallback(curProError, NRLOGINTCOMPCARD); // Plate Error
                }
            });
        }
    },
    async execProc(name, params){
        let status = "SUCCESS";
        let data = [];
        try {
            data = await BD.execProc(name, params);
        } catch ( error ){
            data = ExceptionHandler.getErrorMessage(error);
            status = ExceptionHandler.statusHandler(error);
        }
        return {
            status,
            data
        };
    },
    async execProcIntegracaoCardapio(nrlogintcardmes, NRCENARIOCARD){
        const procedureName = 'INTEGRA_CARDAPIO_WEBSERVICE';
        const params = Object.assign(
            BD.createParam('P_NRLOGINTCARDAMES',   parseInt(nrlogintcardmes), 'IN', 'NUMBER'),
            BD.createParam('P_IDERRO',            null,            'OUT', 'STRING', 1),
            BD.createParam('P_NRCENARIOCARD',     parseInt(NRCENARIOCARD),   'IN', 'NUMBER')
        );
        const result = await this.execProc(procedureName, params);
        const IDERRO = result.P_IDERRO;
        return IDERRO;
    },
    async saveLogIntCompCard(nrlogintcardames, nrlogintcardadia, indexDia, prato, indexPrato, NRORG){
        const SQL_INSERT_LOGINTCOMPCARD = `INSERT INTO LOGINTCOMPCARD (NRLOGINTCOMPCARD, NRLOGINTCARDAMES, NRLOGINTCARDADIA, CDFILAUXPRAT, CDPRATO, NRSEQPRATCAR, CDTIPOPRAT, VRPECONSCARD) VALUES (:NRLOGINTCOMPCARD, :NRLOGINTCARDAMES, :NRLOGINTCARDADIA, :CDFILAUXPRAT, :CDPRATO, :NRSEQPRATCAR, :CDTIPOPRAT, :VRPECONSCARD)`;
        prato.tipoPrato = prato.COD_TIP_PRATO;
        prato.nrPratoCardapio = prato.sequencial;
        let [ FIRST_CHAR ] = prato.prato;
        if( FIRST_CHAR == 'P'){
           prato.unidadePrato = 'P';
           prato.prato = prato.prato.substr(1);
        } else if(prato.prato.length > 9){
            prato.unidadePrato = prato.prato.substr(0, 4);
            prato.prato = prato.prato.substr(4);
        }
        const KEYS_DISH = Object.keys(prato); 
        const ARRAY_DIFF = this.arrayDiff(this.PRATO_PARAMS, KEYS_DISH);
        if (!ARRAY_DIFF.length) {
            let nrlogintcompcard = await NovoCodigo.getCodeByTableNameNT("LOGINTCOMPCARD", NRORG);
            const parameters = {
                "NRLOGINTCOMPCARD": nrlogintcompcard,
                "NRLOGINTCARDAMES": nrlogintcardames,
                "NRLOGINTCARDADIA": nrlogintcardadia,
                "CDPRATO"         : prato.prato,
                "CDFILAUXPRAT"    : prato.unidadePrato,
                "NRSEQPRATCAR"    : prato.nrPratoCardapio,
                "CDTIPOPRAT"      : prato.tipoPrato,
                "VRPECONSCARD"    : parseFloat(parseFloat(prato.percentualConsumo).toFixed(2))
            };
            const result = await BD.execSQL(SQL_INSERT_LOGINTCOMPCARD, parameters).catch(error => {
                console.log('error logintcompcard');
                console.log(parameters);
            });
        } else {
            const erro = `Parâmetros faltando na requisição. ( ${ARRAY_DIFF} )`;
            this.callback.hasErrors = true;
            this.callback.cardapio.datas[indexDia].pratos[indexPrato].erros = [];
            this.callback.cardapio.datas[indexDia].pratos[indexPrato].erros.push( erro );
        }
    },
    async saveLogIntCardaDia(nrlogintcardames, dia, indexDia, NRORG){
        const SQL_INSERT_LOGINTCARDADIA = `INSERT INTO LOGINTCARDADIA (NRLOGINTCARDADIA, NRLOGINTCARDAMES, DTCARDAPIO, QTCOMESTICAR, QTCLIESTICAR, QTFUNESTICAR, QTDOAESTICAR) VALUES (:NRLOGINTCARDADIA, :NRLOGINTCARDAMES, :DTCARDAPIO, :QTCOMESTICAR, :QTCLIESTICAR, :QTFUNESTICAR, :QTDOAESTICAR)`;
        let diff = this.arrayDiff(this.DIA_PARAMS, Object.keys(dia));
        if (!diff.length) {
            let nrlogintcardadia = await NovoCodigo.getCodeByTableNameNT("LOGINTCARDADIA", NRORG);
            let queryParameters = {
                "NRLOGINTCARDAMES": nrlogintcardames,
                "NRLOGINTCARDADIA": nrlogintcardadia,
                "DTCARDAPIO": dia.dia,
                "QTCOMESTICAR": dia.comensais,
                "QTCLIESTICAR": dia.comenCLI,
                "QTFUNESTICAR": dia.comenFUN,
                "QTDOAESTICAR": dia.comenDOA,
            };
            let result = await BD.execSQL(SQL_INSERT_LOGINTCARDADIA, queryParameters);
            if (Array.isArray(dia.pratos)) {
                let pratos = dia.pratos;
                let promises = [];
                dia.pratos.forEach( (prato, key) => {
                    promises.push(this.saveLogIntCompCard(nrlogintcardames, nrlogintcardadia, indexDia, prato, key, NRORG));
                });
                return Promise.all(promises);
            } else {
                this.callback.hasErrors = true;
                this.callback.cardapio.datas[indexDia].erros = [];
                erro = `A propriedade 'pratos' deve ser um array.`;
                this.callback.cardapio.datas[indexDia].erros.push( erro );
            }
        } else {
            erro = `Parâmetros faltando na requisição. ( ${diff} )`;
            this.callback.hasErrors = true;
            this.callback.cardapio.datas[indexDia].erros = [];
            this.callback.cardapio.datas[indexDia].erros.push( erro );
        }
    },
    async saveLogIntCardaMes(nrlogintcardames, params){
        const SQL_INSERT_LOGINTCARDAMES = `INSERT INTO LOGINTCARDAMES (NRLOGINTCARDAMES, DTLOGINT, CDFILIAL, CDSERVFILI, DTMESCARD, CDOPERADOR, DSARQIMPORT) VALUES (:NRLOGINTCARDAMES, SYSDATE, :CDFILIAL, :CDSERVFILI, :DTMESCARD, :CDOPERADOR, :DSARQIMPORT)`;

        let diff = this.arrayDiff(this.REQUEST_PARAMS, Object.keys(params));
        let queryParameters = {};
        if (!diff.length) {
            diff = this.arrayDiff(this.CARDAPIO_PARAMS, Object.keys(params.cardapio));
            if (!diff.length) {
                let cardapio = params.cardapio;
                queryParameters = {
                    "NRLOGINTCARDAMES": nrlogintcardames,
                    "CDFILIAL": cardapio.unidade,
                    "CDSERVFILI": cardapio.servico,
                    "DTMESCARD": cardapio.mes,
                    "CDOPERADOR": cardapio.operador, // QUESTION operador do cardapio ou logado
                    "DSARQIMPORT": JSON.stringify(params)
                };
            } else {
                erro = `Parâmetros faltando na requisição. ( ${diff} )`;
                this.callback.hasErrors = true;
                this.callback.cardapio.erros = [];
                this.callback.cardapio.erros.push( erro );
                cardapio = params.cardapio;
                queryParameters = {
                    "NRLOGINTCARDAMES": nrlogintcardames,
                    "CDFILIAL"        : isset(cardapio.unidade)  ? cardapio.unidade  : null,
                    "CDSERVFILI"      : isset(cardapio.servico)  ? cardapio.servico  : null,
                    "DTMESCARD"       : isset(cardapio.mes)      ? cardapio.mes      : null,
                    "CDOPERADOR"      : isset(cardapio.operador) ? cardapio.operador : null,
                    "DSARQIMPORT"     : JSON.stringify(params),
                };
            }
        } else {
            erro = `Parâmetros faltando na requisição. ( ${diff} )`;
            this.callback.hasErrors = true;
            this.callback.erros = [];
            this.callback.erros.push( erro );
            queryParameters = {
                "NRLOGINTCARDAMES": nrlogintcardames,
                "CDFILIAL"   : null,
                "CDSERVFILI" : null,
                "DTMESCARD"  : null,
                "CDOPERADOR" : null,
                "DSARQIMPORT": JSON.stringify(params),
            };
        }
        let result = await BD.execSQL(SQL_INSERT_LOGINTCARDAMES, queryParameters);
        return result;
    },
    async getCenarioCard( NRCENARIOCARD ){
        const SQL_CENARIOCARD = `SELECT JSONCENARIO FROM CENARIOCARD WHERE NRCENARIOCARD = :P_NRCENARIOCARD`;
        const result = await BD.execQuery(SQL_CENARIOCARD, {
            P_NRCENARIOCARD: {val: NRCENARIOCARD}
        });
        if(Array.isArray(result)){
            const [ CENARIO ] = result;
            return JSON.parse(CENARIO.JSONCENARIO).cardapio;
        }
        return null;
    },
    getResolvedPromise(){
        return new Promise(
            (resolve, reject) => {
                resolve({
                    status: "SUCCESS",
                    data: []
                })
            }
        );
    },
    async integracaoCardapio( parameters, socket ){
        try {
            const { NRCENARIOCARD, NRITGERACAOCARD, NRORG, ROW_ID } = parameters;
            let promises = [this.getResolvedPromise()];
            parameters.cardapio = await this.getCenarioCard( NRCENARIOCARD );
            this.callback = parameters;
            this.callback.hasErrors = false;
            let nrlogintcardames = await NovoCodigo.getCodeByTableName("LOGINTCARDAMES", NRORG);
            let resultCardaMes = await this.saveLogIntCardaMes(nrlogintcardames, parameters);
            console.log(`Finish saveLogIntCardaMes`);
            if (!this.callback.hasErrors) {
                let datas = parameters.cardapio.datas;
                if (Array.isArray(datas)) {
                    datas.forEach( (dia, key) => {
                        promises.push(this.saveLogIntCardaDia(nrlogintcardames, dia, key, NRORG));
                    });
                } else {
                    this.callback.hasErrors = true;
                    this.callback.cardapio.erros = [];
                    erro = `A propriedade 'datas' deve ser um array.`;
                    this.callback.cardapio.erros.push( erro );
                }
                let resolvePromiseProc = ()=>{};
                let rejectPromiseProc = ()=>{};
                let promiseProcedure = new Promise((resolve, reject) => {
                    resolvePromiseProc = resolve;
                    rejectPromiseProc = reject;
                });
                Promise.all(promises).then( async _ => {
                    try {
                        console.log(`Finish promises, before procedure`);
                        if (!this.callback.hasErrors) {
                            let P_IDERRO = await this.execProcIntegracaoCardapio(nrlogintcardames, NRCENARIOCARD);
                            console.log(`Finish call procedure`);
                            resolvePromiseProc(P_IDERRO);
                            const HAS_ERROR = P_IDERRO === 'S';
                            const STATUS = HAS_ERROR ? "PUBLICADO_COM_ERRO" : "PUBLICADO_SEM_ERRO";
                            const responseStatus = await Status.updateStatusItGeracaoCard(NRITGERACAOCARD, STATUS);
                            if (HAS_ERROR) {
                                this.callback.hasErrors = true;
                                this.setErrorsFromProcedure(nrlogintcardames);
                                socket.emit('onSocketSceneryBatchMessage', {
                                    NRCENARIOCARD,
                                    NRITGERACAOCARD,
                                    ROW_ID,
                                    STATUS,
                                    OPERATION: "PUBLISH"
                                });
                            } else {
                                socket.emit('onSocketSceneryBatchMessage', {
                                    NRCENARIOCARD,
                                    NRITGERACAOCARD,
                                    ROW_ID,
                                    STATUS,
                                    OPERATION: "PUBLISH"
                                });
                            }
                        } else {
                            resolvePromiseProc('Error callback before call procedure');
                        }
                    }catch( error ){
                        rejectPromiseProc(error);
                    }
                });
                promises.push(promiseProcedure);
            }
            const resultAll = await Promise.all(promises);
            return this.handleCallback();
        } catch ( error ) {
            console.log(error.message);
            //throw error;
        }
    }
};
export default IntegracaoCardapio;
/** -- PHP
    function integracaoCardapio(DTO\Request $request, DTO\Response $response)
    {
        try {
            // $this->sqlLogger->setLogRoute("/integracaoCardapio");
            // $this->connection->getConfiguration()->setSQLLogger($this->sqlLogger);
            $parameters = $request->getParameters()['row'];
            // var_dump($parameters);die;
            $this->callback = $parameters;
            $this->callback["hasErrors"] = false;
            $nrlogintcardames = $this->newCode->getCodeByTableName("LOGINTCARDAMES", self::NRORG);
            $this->saveLogintcardames($nrlogintcardames, $parameters);

            if (!$this->callback["hasErrors"]) {
                $datas = $parameters["cardapio"]["datas"];
                $NRCENARIOCARD = $parameters["NRCENARIOCARD"];
                if (is_array($datas)) {
                    foreach ($datas as $key => $dia) {
                        $this->saveLogintcardadia($nrlogintcardames, $dia, $key);
                    }
                } else {
                    $this->callback["hasErrors"] = true;
                    $this->callback["cardapio"]["erros"] = array();
                    $erro = "A propriedade 'datas' deve ser um array.";
                    array_push($this->callback["cardapio"]["erros"], $erro);
                }
                if (!$this->callback["hasErrors"]) {
                    $this->connection->beginTransaction();
                    $p_erros = $this->executeProcedure($nrlogintcardames, $NRCENARIOCARD);
                    $this->connection->commit();
                    if ($p_erros['P_IDERRO'] == "S") {
                        $this->callback["hasErrors"] = true;
                        $this->setErrorsFromProcedure($nrlogintcardames);
                    }
                }
            }
            $this->handleCallback($response);
        } catch (\Exception $e) {
            // var_dump('Erro durante a integracaoCardapio, podem ser os parametros.');
            var_dump($e);
            error_log($e);
            throw $e;
        }
    }

    function saveLogintcardames($nrlogintcardames, $params)
    {
        $sql = "INSERT INTO LOGINTCARDAMES (NRLOGINTCARDAMES, DTLOGINT, CDFILIAL, CDSERVFILI, DTMESCARD, CDOPERADOR, DSARQIMPORT) VALUES (:NRLOGINTCARDAMES, SYSDATE, :CDFILIAL, :CDSERVFILI, :DTMESCARD, :CDOPERADOR, :DSARQIMPORT)";
        $currentTime = new \DateTime();
        $currentTime = $currentTime->format("d/m/Y H:i:s");

        $diff = array_diff(self::REQUEST_PARAMS, array_keys($params));
        if (empty($diff)) {
            $diff = array_diff(self::CARDAPIO_PARAMS, array_keys($params["cardapio"]));
            if (empty($diff)) {
                $cardapio = $params["cardapio"];
                $queryParameters = array(
                    "NRLOGINTCARDAMES" => $nrlogintcardames,
                    // "DTLOGINT" => $currentTime,
                    "CDFILIAL" => $cardapio["unidade"],
                    "CDSERVFILI" => $cardapio["servico"],
                    "DTMESCARD" => $cardapio["mes"],
                    "CDOPERADOR" => $cardapio["operador"],
                    "DSARQIMPORT" => json_encode($params),
                );
            } else {
                $erro = "Parâmetros faltando na requisição. (" . implode(", ", $diff) . ")";
                $this->callback["hasErrors"] = true;
                $this->callback["cardapio"]["erros"] = array();
                array_push($this->callback["cardapio"]["erros"], $erro);
                $cardapio = $params["cardapio"];
                $queryParameters = array(
                    "NRLOGINTCARDAMES" => $nrlogintcardames,
                    "DTLOGINT" => $currentTime,
                    "CDFILIAL" => isset($cardapio["unidade"]) ? $cardapio["unidade"] : null,
                    "CDSERVFILI" => isset($cardapio["servico"]) ? $cardapio["servico"] : null,
                    "DTMESCARD" => isset($cardapio["mes"]) ? $cardapio["mes"] : null,
                    "CDOPERADOR" => isset($cardapio["operador"]) ? $cardapio["operador"] : null,
                    "DSARQIMPORT" => json_encode($params),
                );
            }
        } else {
            $erro = "Parâmetros faltando na requisição. (" . implode(", ", $diff) . ")";
            $this->callback["hasErrors"] = true;
            $this->callback["erros"] = array();
            array_push($this->callback["erros"], $erro);
            $queryParameters = array(
                "NRLOGINTCARDAMES" => $nrlogintcardames,
                "DTLOGINT" => $currentTime,
                "CDFILIAL" => null,
                "CDSERVFILI" => null,
                "DTMESCARD" => null,
                "CDOPERADOR" => null,
                "DSARQIMPORT" => json_encode($params),
            );
        }
        $query = $this->connection->prepare($sql);
        $query->execute($queryParameters);
    }

    function saveLogintcardadia($nrlogintcardames, $dia, $indexDia)
    {
        $sql = "INSERT INTO LOGINTCARDADIA (NRLOGINTCARDADIA, NRLOGINTCARDAMES, DTCARDAPIO, QTCOMESTICAR, QTCLIESTICAR, QTFUNESTICAR, QTDOAESTICAR) VALUES (:NRLOGINTCARDADIA, :NRLOGINTCARDAMES, :DTCARDAPIO, :QTCOMESTICAR, :QTCLIESTICAR, :QTFUNESTICAR, :QTDOAESTICAR)";
        $diff = array_diff(self::DIA_PARAMS, array_keys($dia));
        if (empty($diff)) {
            $nrlogintcardadia = $this->newCodeNT->getCodeByTableName("LOGINTCARDADIA", self::NRORG);
            $queryParameters = array(
                "NRLOGINTCARDAMES" => $nrlogintcardames,
                "NRLOGINTCARDADIA" => $nrlogintcardadia,
                "DTCARDAPIO" => $dia["dia"],
                "QTCOMESTICAR" => $dia["comensais"],
                "QTCLIESTICAR" => $dia["comenCLI"],
                "QTFUNESTICAR" => $dia["comenFUN"],
                "QTDOAESTICAR" => $dia["comenDOA"],
            );
            $query = $this->connection->prepare($sql);
            $query->execute($queryParameters);
            if (is_array($dia["pratos"])) {
                $pratos = $dia["pratos"];
                foreach ($pratos as $key => $prato) {
                    $this->saveLogintcompcard($nrlogintcardames, $nrlogintcardadia, $indexDia, $prato, $key);
                }
            } else {
                $this->callback["hasErrors"] = true;
                $this->callback["cardapio"]["datas"][$indexDia]["erros"] = array();
                $erro = "A propriedade 'pratos' deve ser um array.";
                array_push($this->callback["cardapio"]["datas"][$indexDia]["erros"], $erro);
            }
        } else {
            $erro = "Parâmetros faltando na requisição. (" . implode(", ", $diff) . ")";
            $this->callback["hasErrors"] = true;
            $this->callback["cardapio"]["datas"][$indexDia]["erros"] = array();
            array_push($this->callback["cardapio"]["datas"][$indexDia]["erros"], $erro);
        }
    }

    function saveLogintcompcard($nrlogintcardames, $nrlogintcardadia, $indexDia, $prato, $indexPrato)
    {
        $sql = "INSERT INTO LOGINTCOMPCARD (NRLOGINTCOMPCARD, NRLOGINTCARDAMES, NRLOGINTCARDADIA, CDFILAUXPRAT, CDPRATO, NRSEQPRATCAR, CDTIPOPRAT, VRPECONSCARD) VALUES (:NRLOGINTCOMPCARD, :NRLOGINTCARDAMES, :NRLOGINTCARDADIA, :CDFILAUXPRAT, :CDPRATO, :NRSEQPRATCAR, :CDTIPOPRAT, :VRPECONSCARD)";
        
        $prato["tipoPrato"] = $prato["COD_TIP_PRATO"];
        $prato["nrPratoCardapio"] = $prato["sequencial"];
        if( substr($prato["prato"], 0, 1) == 'P'){
           $prato["unidadePrato"] = 'P';
           $prato["prato"] = substr($prato["prato"], 1);
        } else if(strlen($prato["prato"]) > 9){
            $prato["unidadePrato"] = substr($prato["prato"], 0, 4);
            $prato["prato"] = substr($prato["prato"], 4);
        }

        $diff = array_diff(self::PRATO_PARAMS, array_keys($prato));
        
        if (empty($diff)) {
            $nrlogintcompcard = $this->newCodeNT->getCodeByTableName("LOGINTCOMPCARD", self::NRORG);
            $queryParameters = array(
                "NRLOGINTCOMPCARD" => $nrlogintcompcard,
                "NRLOGINTCARDAMES" => $nrlogintcardames,
                "NRLOGINTCARDADIA" => $nrlogintcardadia,
                "CDPRATO" => $prato["prato"],
                "CDFILAUXPRAT" => $prato["unidadePrato"],
                "NRSEQPRATCAR" => $prato["nrPratoCardapio"],
                "CDTIPOPRAT" => $prato["tipoPrato"],
                "VRPECONSCARD" => $prato["percentualConsumo"],
            );
            $query = $this->connection->prepare($sql);
            $query->execute($queryParameters);
        } else {
            $erro = "Parâmetros faltando na requisição. (" . implode(", ", $diff) . ")";
            $this->callback["hasErrors"] = true;
            $this->callback["cardapio"]["datas"][$indexDia]["pratos"][$indexPrato]["erros"] = array();
            array_push($this->callback["cardapio"]["datas"][$indexDia]["pratos"][$indexPrato]["erros"], $erro);
        }
    }

    function executeProcedure($nrlogintcardmes, $NRCENARIOCARD)
    {
        $procedure = new StoredProcedure($this->connection, 'INTEGRA_CARDAPIO_WEBSERVICE');
        $procedure->addParam(new Param('P_NRLOGINTCARDMES', Param::PARAM_INPUT, $nrlogintcardmes, Param::PARAM_TYPE_STR, 10));
        $procedure->addParam(new Param('P_IDERRO', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 10));
        $procedure->addParam(new Param('P_NRCENARIOCARD', Param::PARAM_INPUT, $NRCENARIOCARD, Param::PARAM_TYPE_STR, 10));
        return $procedure->execute();
    }
*/